@@ -1,6 +1,6 @@
 /* A sort of clone of the cddlib test program `lcdd'.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,7 +19,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 //#define USE_POLKA 1
 //#define USE_POLYLIB 1
@@ -30,7 +30,7 @@ site: http://www.cs.unipr.it/ppl/ . */
    (defined(USE_PPL)   && defined(USE_POLKA)) \
 || (defined(USE_PPL)   && defined(USE_POLYLIB)) \
 || (defined(USE_POLKA) && defined(USE_POLYLIB))
-#error "Exactly one among USE_PPL, USE_POLKA and USE_POLYLIB must be defined."
+#error "Exactly one among USE_PPL, USE_POLKA and USE_POLYLIB must be defined"
 #endif
 
 #if defined(USE_PPL)
@@ -141,6 +141,7 @@ typedef Polyhedron* POLYHEDRON_TYPE;
 #endif
 
 #if defined(PPL_HAVE_SYS_RESOURCE_H) \
+  && PPL_CXX_SUPPORTS_LIMITING_MEMORY \
   && (defined(SA_ONESHOT) || defined(SA_RESETHAND))
 # define PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
 #endif
@@ -240,7 +241,7 @@ set_input(const char* file_name) {
 
 std::istream&
 input() {
-  assert(input_stream_p);
+  assert(input_stream_p != 0);
   return *input_stream_p;
 }
 
@@ -268,7 +269,7 @@ set_output(const char* file_name) {
 
 std::ostream&
 output() {
-  assert(output_stream_p);
+  assert(output_stream_p != 0);
   return *output_stream_p;
 }
 
@@ -300,7 +301,7 @@ warning(const char* format, ...) {
 extern "C" typedef void (*sig_handler_type)(int);
 
 void
-set_alarm_on_cpu_time(const unsigned seconds, sig_handler_type handler) {
+set_alarm_on_cpu_time(const unsigned long seconds, sig_handler_type handler) {
   sigset_t mask;
   sigemptyset(&mask);
 
@@ -331,7 +332,7 @@ set_alarm_on_cpu_time(const unsigned seconds, sig_handler_type handler) {
 
 #endif // PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
 
-#if PPL_HAVE_DECL_RLIMIT_AS
+#if PPL_CXX_SUPPORTS_LIMITING_MEMORY && PPL_HAVE_DECL_RLIMIT_AS
 
 void
 limit_virtual_memory(const unsigned long bytes) {
@@ -414,13 +415,16 @@ process_options(int argc, char* argv[]) {
 #endif // defined(PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME)
 
     case 'R':
-      l = strtol(optarg, &endptr, 10);
-      if (*endptr || l < 0)
-	fatal("a non-negative integer must follow `-R'");
-      else if (((unsigned long) l) > ULONG_MAX/(1024*1024))
-        max_bytes_of_virtual_memory = ULONG_MAX;
-      else
-	max_bytes_of_virtual_memory = l*1024*1024;
+      {
+        const int MEGA = 1024*1024;
+        l = strtol(optarg, &endptr, 10);
+        if (*endptr || l < 0)
+          fatal("a non-negative integer must follow `-R'");
+        else if (static_cast<unsigned long>(l) > ULONG_MAX/MEGA)
+          max_bytes_of_virtual_memory = ULONG_MAX;
+        else
+          max_bytes_of_virtual_memory = l*MEGA;
+      }
       break;
 
     case 'o':
@@ -485,13 +489,14 @@ void
 normalize(const std::vector<mpq_class>& source,
 	  std::vector<mpz_class>& dest,
 	  mpz_class& denominator) {
-  unsigned n = source.size();
+  typedef std::vector<mpq_class>::size_type size_type;
+  size_type n = source.size();
   denominator = 1;
-  for (unsigned i = 0; i < n; ++i)
+  for (size_type i = 0; i < n; ++i)
     mpz_lcm(denominator.get_mpz_t(),
 	    denominator.get_mpz_t(),
 	    source[i].get_den().get_mpz_t());
-  for (unsigned i = 0; i < n; ++i)
+  for (size_type i = 0; i < n; ++i)
     dest[i] = denominator*source[i];
 }
 
@@ -541,7 +546,8 @@ read_coefficients(std::istream& in,
 		  const Number_Type number_type,
 		  std::vector<mpz_class>& coefficients,
 		  mpz_class& denominator) {
-  unsigned num_coefficients = coefficients.size();
+  typedef std::vector<mpz_class>::size_type size_type;
+  size_type num_coefficients = coefficients.size();
   switch (number_type) {
   case INTEGER:
     {
@@ -633,8 +639,8 @@ read_polyhedron(std::istream& in, POLYHEDRON_TYPE& ph) {
   if (!guarded_read(in, s))
     error("missing number of rows");
   if (s != "*****") {
-    std::istringstream istr(s);
-    if (!guarded_read(istr, num_rows))
+    std::istringstream iss(s);
+    if (!guarded_read(iss, num_rows))
       error("illegal number of rows `%s' (\"*****\" would be accepted)",
 	    s.c_str());
     has_num_rows = true;
@@ -704,8 +710,8 @@ read_polyhedron(std::istream& in, POLYHEDRON_TYPE& ph) {
 	  error("missing vertex marker");
 	if (s == "end")
 	  break;
-	std::istringstream istr(s);
-	if (!guarded_read(istr, vertex_marker)
+	std::istringstream iss(s);
+	if (!guarded_read(iss, vertex_marker)
 	    || vertex_marker < 0 || vertex_marker > 1)
 	  error("illegal vertex marker `%s'", s.c_str());
       }
@@ -831,8 +837,8 @@ read_polyhedron(std::istream& in, POLYHEDRON_TYPE& ph) {
 		"for coefficients or `end'");
 	if (s.substr(0, 2) == "end")
 	  break;
-	std::istringstream istr(s);
-	read_coefficients(istr, number_type, coefficients, denominator);
+	std::istringstream iss(s);
+	read_coefficients(iss, number_type, coefficients, denominator);
       }
       else
 	read_coefficients(in, number_type, coefficients, denominator);
@@ -1051,12 +1057,12 @@ write_polyhedron(std::ostream& out,
 	  if (g.coefficient(PPL::Variable(j)) == 0)
 	    guarded_write(out, '0');
 	  else {
-	    mpz_class num, den;
-	    PPL::assign_r(num,
+	    mpz_class numer, denom;
+	    PPL::assign_r(numer,
 			g.coefficient(PPL::Variable(j)),
 			PPL::ROUND_NOT_NEEDED);
-	    PPL::assign_r(den, divisor, PPL::ROUND_NOT_NEEDED);
-	    guarded_write(out, mpq_class(num, den));
+	    PPL::assign_r(denom, divisor, PPL::ROUND_NOT_NEEDED);
+	    guarded_write(out, mpq_class(numer, denom));
 	  }
 	}
       }
@@ -1186,7 +1192,7 @@ main(int argc, char* argv[]) try {
 #ifdef PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
 
   if (max_seconds_of_cpu_time > 0)
-    set_alarm_on_cpu_time(max_seconds_of_cpu_time, timeout);
+    set_alarm_on_cpu_time(max_seconds_of_cpu_time, &timeout);
 
 #endif // defined(PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME)
 
