@@ -1,6 +1,6 @@
 /* Test the timeout facility of the PPL C interface library.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,7 +19,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl_c_test.h"
 #include <stdlib.h>
@@ -50,12 +50,12 @@ error_handler(enum ppl_enum_error_code code,
 	      const char* description) {
   if (check_noisy() || check_very_noisy())
     fprintf(stderr, "PPL error code %d: %s\n", code, description);
-#if !PWL_WATCHDOG_OBJECTS_ARE_SUPPORTED
+#if !PPL_WATCHDOG_OBJECTS_ARE_SUPPORTED
   /* If Watchdog objects are not supported, a logic error will occur:
      this is normal. */
   if (code == PPL_ERROR_LOGIC_ERROR)
     my_exit(0);
-#endif
+#endif /* !PPL_WATCHDOG_OBJECTS_ARE_SUPPORTED */
 }
 
 void
@@ -102,8 +102,7 @@ open_hypercube(int dimension, ppl_Polyhedron_t ph) {
 }
 
 void
-timed_compute_open_hypercube_generators(int hundredth_secs,
-                                        int max_dimension) {
+timed_compute_open_hypercube_generators(int csecs, int max_dimension) {
   int i;
   int result;
   ppl_const_Generator_System_t gs;
@@ -112,7 +111,7 @@ timed_compute_open_hypercube_generators(int hundredth_secs,
   for (i = 0; i <= max_dimension; ++i) {
     ppl_new_NNC_Polyhedron_from_space_dimension(&ph, i, 0);
     open_hypercube(i, ph);
-    ppl_set_timeout(hundredth_secs);
+    ppl_set_timeout(csecs);
     result = ppl_Polyhedron_get_generators(ph, &gs);
     ppl_reset_timeout();
     ppl_delete_Polyhedron(ph);
