@@ -1,6 +1,6 @@
 /* Parma_Polyhedra_Library Java class declaration and implementation.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,7 +19,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 /*!
   \defgroup PPL_Java_interface Java Language Interface
@@ -240,19 +240,19 @@ public class Parma_Polyhedra_Library {
       Sets the timeout for computations whose completion could require
       an exponential amount of time.
 
-      \param hsecs
-      The number of hundreths of seconds.
-      It must be strictly greater than zero.
+      \param csecs
+      The number of centiseconds sometimes after which a timeout will occur;
+      it must be strictly greater than zero.
 
       Computations taking exponential time will be interrupted some time
-      after \p hsecs hundreths of seconds have elapsed since the call to
+      after \p csecs centiseconds have elapsed since the call to
       the timeout setting function, by throwing a
       <CODE>Timeout_Exception</CODE> object.
       Otherwise, if the computation completes without being interrupted,
       then the timeout should be reset by calling
       <CODE>reset_timeout()</CODE>.
     */
-    public static native void set_timeout(int hsecs);
+    public static native void set_timeout(int csecs);
 
     /*! \brief
       Resets the timeout time so that the computation is not interrupted.
@@ -264,8 +264,8 @@ public class Parma_Polyhedra_Library {
       an exponential amount of time.
 
       \param weight
-      The maximum computational weight allowed.
-      It must be strictly greater than zero.
+      The maximum computational weight allowed; it must be strictly
+      greater than zero.
 
       Computations taking exponential time will be interrupted some time
       after reaching the \p weight complexity threshold, by throwing a
