@@ -1,6 +1,6 @@
 /* Congruence_System class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,10 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Congruence_System.defs.hh"
 #include "Congruence_System.inlines.hh"
 #include "Constraint_System.defs.hh"
@@ -39,7 +38,7 @@ site: http://www.cs.unipr.it/ppl/ . */
 namespace PPL = Parma_Polyhedra_Library;
 
 PPL::Congruence_System::Congruence_System(const Constraint_System& cs)
-  : Matrix(0, cs.space_dimension() + 2) {
+  : Dense_Matrix(0, cs.space_dimension() + 2) {
   for (Constraint_System::const_iterator i = cs.begin(),
 	 cs_end = cs.end(); i != cs_end; ++i)
     if (i->is_equality())
@@ -53,8 +52,8 @@ increase_space_dimension(const dimension_type new_space_dim) {
 
   const dimension_type cols_to_add = new_space_dim - space_dimension();
 
-  if (cols_to_add) {
-    if (num_rows()) {
+  if (cols_to_add > 0) {
+    if (num_rows() > 0) {
       const dimension_type old_num_columns = num_columns();
       add_zero_columns(cols_to_add);
       // Move the moduli.
@@ -86,7 +85,8 @@ PPL::Congruence_System::insert_verbatim(const Congruence& cg) {
     // Create a resized copy of `cg'.
     Congruence rc(cg, old_num_columns, row_capacity);
     // Move the modulus to its place.
-    std::swap(rc[cg_size - 1], rc[old_num_columns - 1]);
+    using std::swap;
+    swap(rc[cg_size - 1], rc[old_num_columns - 1]);
     add_recycled_row(rc);
   }
   else
@@ -116,7 +116,7 @@ PPL::Congruence_System::insert(const Constraint& c) {
     Congruence cg(c, cg_size, row_capacity);
     add_recycled_row(cg);
   }
-  operator[](rows.size()-1).strong_normalize();
+  (*this)[rows.size()-1].strong_normalize();
 
   PPL_ASSERT(OK());
 }
@@ -128,11 +128,11 @@ PPL::Congruence_System::recycling_insert(Congruence_System& cgs) {
   const dimension_type old_num_columns = num_columns();
   dimension_type cgs_num_columns = cgs.num_columns();
   if (old_num_columns >= cgs_num_columns)
-    add_zero_rows(cgs_num_rows, Row::Flags());
+    add_zero_rows(cgs_num_rows, Dense_Row::Flags());
   else {
     add_zero_rows_and_columns(cgs_num_rows,
-			      cgs_num_columns - old_num_columns,
-			      Row::Flags());
+                              cgs_num_columns - old_num_columns,
+                              Dense_Row::Flags());
     // Swap the modulus column into the new last column.
     swap_columns(old_num_columns - 1, num_columns() - 1);
   }
@@ -142,11 +142,12 @@ PPL::Congruence_System::recycling_insert(Congruence_System& cgs) {
     // Swap one coefficient at a time into the newly added rows, instead
     // of swapping each entire row.  This ensures that the added rows
     // have the same capacities as the existing rows.
-    Congruence& new_cg = operator[](old_num_rows + i);
+    using std::swap;
+    Congruence& new_cg = (*this)[old_num_rows + i];
     Congruence& old_cg = cgs[i];
     for (dimension_type j = cgs_num_columns; j-- > 0; )
-      std::swap(new_cg[j], old_cg[j]);
-    std::swap(new_cg[mod_index], old_cg[cgs_num_columns]); // Modulus.
+      swap(new_cg[j], old_cg[j]);
+    swap(new_cg[mod_index], old_cg[cgs_num_columns]); // Modulus.
   }
 
   PPL_ASSERT(OK());
@@ -162,11 +163,11 @@ PPL::Congruence_System::insert(const Congruence_System& y) {
   const dimension_type y_num_columns = y.num_columns();
   // Grow to the required size.
   if (old_num_columns >= y_num_columns)
-    add_zero_rows(y_num_rows, Row::Flags());
+    add_zero_rows(y_num_rows, Dense_Row::Flags());
   else {
     add_zero_rows_and_columns(y_num_rows,
-			      y_num_columns - old_num_columns,
-			      Row::Flags());
+                              y_num_columns - old_num_columns,
+                              Dense_Row::Flags());
     // Swap the modulus column into the new last column.
     swap_columns(old_num_columns - 1, num_columns() - 1);
   }
@@ -175,23 +176,26 @@ PPL::Congruence_System::insert(const Congruence_System& y) {
   const dimension_type x_mod_index = x.num_columns() - 1;
   const dimension_type y_mod_index = y_num_columns - 1;
   for (dimension_type i = y_num_rows; i-- > 0; ) {
-    Row copy(y[i], x.row_size, x.row_capacity);
+    Dense_Row copy(y[i], x.row_size, x.row_capacity);
     // Swap the modulus to the correct column.
-    std::swap(copy[x_mod_index], copy[y_mod_index]);
-    std::swap(copy, x[x_num_rows+i]);
+    using std::swap;
+    swap(copy[x_mod_index], copy[y_mod_index]);
+    swap(copy, x[x_num_rows+i]);
   }
   PPL_ASSERT(OK());
 }
 
 void
 PPL::Congruence_System::normalize_moduli() {
-  dimension_type row = num_rows();
+  Congruence_System& cgs = *this;
+  dimension_type row = cgs.num_rows();
   if (row > 0) {
     // Calculate the LCM of all the moduli.
     PPL_DIRTY_TEMP_COEFFICIENT(lcm);
     // Find last proper congruence.
     while (true) {
-      lcm = operator[](--row).modulus();
+      --row;
+      lcm = cgs[row].modulus();
       if (lcm > 0)
 	break;
       if (row == 0)
@@ -199,38 +203,45 @@ PPL::Congruence_System::normalize_moduli() {
 	return;
     }
     while (row > 0) {
-      const Coefficient& modulus = operator[](--row).modulus();
+      --row;
+      const Coefficient& modulus = cgs[row].modulus();
       if (modulus > 0)
 	lcm_assign(lcm, lcm, modulus);
     }
 
     // Represent every row using the LCM as the modulus.
     PPL_DIRTY_TEMP_COEFFICIENT(factor);
-    dimension_type row_size = operator[](0).size();
-    for (row = num_rows(); row-- > 0; ) {
-      const Coefficient& modulus = operator[](row).modulus();
+    dimension_type row_size = cgs[0].size();
+    for (row = cgs.num_rows(); row-- > 0; ) {
+      Congruence& cgs_row = cgs[row];
+      const Coefficient& modulus = cgs_row.modulus();
       if (modulus <= 0 || modulus == lcm)
 	continue;
       exact_div_assign(factor, lcm, modulus);
-      for (dimension_type col = row_size; col-- > 0; )
-	operator[](row)[col] *= factor;
-      operator[](row)[row_size-1] = lcm;
+      for (dimension_type col = row_size; col-- > 0; ) {
+	cgs_row[col] *= factor;
+      }
+      cgs_row[row_size-1] = lcm;
     }
   }
   PPL_ASSERT(OK());
 }
 
 bool
-PPL::Congruence_System::is_equal_to(const Congruence_System& cgs) const {
-  if (num_rows() != cgs.num_rows())
+PPL::Congruence_System::is_equal_to(const Congruence_System& y) const {
+  const Congruence_System& x = *this;
+  if (x.num_rows() != y.num_rows())
     return false;
 
-  for (dimension_type row = cgs.num_rows(); row-- > 0; )
-    for (dimension_type col = cgs.num_columns(); col-- > 0; ) {
-      if (operator[](row)[col] == cgs[row][col])
+  for (dimension_type row = y.num_rows(); row-- > 0; ) {
+    const Congruence& x_row = x[row];
+    const Congruence& y_row = y[row];
+    for (dimension_type col = y.num_columns(); col-- > 0; ) {
+      if (x_row[col] == y_row[col])
 	continue;
       return false;
     }
+  }
   return true;
 }
 
@@ -246,7 +257,7 @@ PPL::Congruence_System::has_linear_equalities() const {
 
 void
 PPL::Congruence_System::const_iterator::skip_forward() {
-  const Matrix::const_iterator csp_end = csp->end();
+  const Dense_Matrix::const_iterator csp_end = csp->end();
   while (i != csp_end && (*this)->is_tautological())
     ++i;
 }
@@ -311,7 +322,7 @@ PPL::Congruence_System::has_a_free_dimension() const {
   std::vector<bool> free_dim(space_dim, true);
   dimension_type free_dims = space_dim;
   for (dimension_type row = num_rows(); row-- > 0; ) {
-    const Congruence& cg = operator[](row);
+    const Congruence& cg = (*this)[row];
     for (dimension_type dim = space_dim; dim-- > 0; )
       if (free_dim[dim] && cg[dim+1] != 0) {
 	if (--free_dims == 0) {
@@ -321,8 +332,10 @@ PPL::Congruence_System::has_a_free_dimension() const {
 	  // Check that there are free_dims dimensions marked free
 	  // in free_dim.
 	  dimension_type count = 0;
-	  for (dimension_type i = space_dim; i-- > 0; )
-	    count += free_dim[i];
+	  for (dimension_type i = space_dim; i-- > 0; ) {
+	    if (free_dim[i])
+              ++count;
+          }
 	  PPL_ASSERT(count == free_dims);
 #endif
 	  return true;
@@ -395,7 +408,7 @@ PPL::Congruence_System::ascii_dump(std::ostream& s) const {
   dimension_type x_num_columns = x.num_columns();
   s << x_num_rows << " x " << x_num_columns
     << std::endl;
-  if (x_num_rows && x_num_columns)
+  if (x_num_rows > 0 && x_num_columns > 0)
     for (dimension_type i = 0; i < x_num_rows; ++i)
       x[i].ascii_dump(s);
 }
@@ -443,11 +456,11 @@ PPL::Congruence_System::finalize() {
 
 bool
 PPL::Congruence_System::OK() const {
-  // A Congruence_System must be a valid Matrix.
-  if (!Matrix::OK())
+  // A Congruence_System must be a valid Dense_Matrix.
+  if (!Dense_Matrix::OK())
     return false;
 
-  if (num_rows()) {
+  if (num_rows() > 0) {
     if (num_columns() < 2) {
 #ifndef NDEBUG
       std::cerr << "Congruence_System has rows and fewer than two columns."
@@ -492,10 +505,9 @@ PPL::operator==(const Congruence_System& x, const Congruence_System& y) {
   if (x.num_columns() == y.num_columns()) {
     dimension_type num_rows = x.num_rows();
     if (num_rows == y.num_rows()) {
-      while (num_rows--) {
-	if (x[num_rows] == y[num_rows])
-	  continue;
-	return false;
+      while (num_rows-- > 0) {
+	if (x[num_rows] != y[num_rows])
+	  return false;
       }
       return true;
     }
@@ -514,14 +526,16 @@ PPL::Congruence_System::add_unit_rows_and_columns(dimension_type dims) {
   // Swap the modulus column into the new last column.
   swap_columns(col, col + dims);
 
+  Congruence_System& cgs = *this;
   // Swap the added columns to the front of the matrix.
+  using std::swap;
   for (dimension_type row = old_num_rows; row-- > 0; )
-    std::swap(operator[](row), operator[](row + dims));
+    swap(cgs[row], cgs[row + dims]);
 
   col += dims - 1;
   // Set the diagonal element of each added row.
   for (dimension_type row = dims; row-- > 0; )
-    const_cast<Coefficient&>(operator[](row)[col - row]) = 1;
+    cgs[row][col - row] = 1;
 }
 
 void
@@ -536,28 +550,29 @@ PPL::Congruence_System::concatenate(const Congruence_System& const_cgs) {
   dimension_type old_modi = num_columns() - 1;
   dimension_type old_space_dim = space_dimension();
 
-  add_zero_rows_and_columns(added_rows, added_columns,
-			    Row::Flags());
+  add_zero_rows_and_columns(added_rows, added_columns, Dense_Row::Flags());
 
   dimension_type cgs_num_columns = cgs.num_columns();
   dimension_type modi = num_columns() - 1;
 
   // Swap the modulus and the new last column, in the old rows.
   for (dimension_type i = old_num_rows; i-- > 0; ) {
-    Congruence& cg = operator[](i);
-    std::swap(cg[old_modi], cg[modi]);
+    Congruence& cg = (*this)[i];
+    using std::swap;
+    swap(cg[old_modi], cg[modi]);
   }
 
   // Move the congruences into *this from `cgs', shifting the
   // coefficients along into the appropriate columns.
   for (dimension_type i = added_rows; i-- > 0; ) {
     Congruence& cg_old = cgs[i];
-    Congruence& cg_new = operator[](old_num_rows + i);
+    Congruence& cg_new = (*this)[old_num_rows + i];
+    using std::swap;
     // The inhomogeneous term is moved to the same column.
-    std::swap(cg_new[0], cg_old[0]);
+    swap(cg_new[0], cg_old[0]);
     // All homogeneous terms are shifted by `space_dim' columns.
     for (dimension_type j = cgs_num_columns; j-- > 1; )
-      std::swap(cg_old[j], cg_new[old_space_dim + j]);
+      swap(cg_old[j], cg_new[old_space_dim + j]);
   }
 }
 
