@@ -1,6 +1,6 @@
 /* Grid class implementation: simplify().
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,11 +19,10 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
-#include <ppl-config.h>
+#include "ppl-config.h"
 #include "assert.hh"
-
 #include "Grid.defs.hh"
 
 namespace Parma_Polyhedra_Library {
@@ -281,8 +280,10 @@ Grid::simplify(Grid_Generator_System& sys, Dimension_Kinds& dim_kinds) {
       // Element in column `dim' is zero in all rows from the pivot.
       dim_kinds[dim] = GEN_VIRTUAL;
     else {
-      if (row_index != pivot_index)
-	std::swap(sys[row_index], sys[pivot_index]);
+      if (row_index != pivot_index) {
+        using std::swap;
+	swap(sys[row_index], sys[pivot_index]);
+      }
       Grid_Generator& pivot = sys[pivot_index];
       bool pivot_is_line = pivot.is_line();
 
@@ -301,7 +302,8 @@ Grid::simplify(Grid_Generator_System& sys, Dimension_Kinds& dim_kinds) {
 	    reduce_line_with_line(row, pivot, dim);
 	  else {
 	    PPL_ASSERT(pivot.is_parameter_or_point());
-	    std::swap(row, pivot);
+            using std::swap;
+	    swap(row, pivot);
 	    pivot_is_line = true;
 	    reduce_parameter_with_line(row, pivot, dim, sys);
 	  }
@@ -349,7 +351,7 @@ Grid::simplify(Grid_Generator_System& sys, Dimension_Kinds& dim_kinds) {
        sys.num_columns() - 1);
     PPL_ASSERT(ret == true);
 #endif
-    sys.erase_to_end(pivot_index);
+    sys.remove_trailing_rows(num_rows - pivot_index);
   }
 
   sys.unset_pending_rows();
@@ -363,8 +365,10 @@ Grid::simplify(Grid_Generator_System& sys, Dimension_Kinds& dim_kinds) {
     switch (dim_kinds[dim]) {
     case PARAMETER:
       sys[row].set_divisor(system_divisor);
+      // Intentionally fall through.
     case LINE:
       --row;
+      // Intentionally fall through.
     case GEN_VIRTUAL:
       break;
     }
@@ -408,8 +412,10 @@ Grid::simplify(Congruence_System& sys, Dimension_Kinds& dim_kinds) {
       dim_kinds[dim] = CON_VIRTUAL;
     else {
       // row_index != num_rows
-      if (row_index != pivot_index)
-	std::swap(sys[row_index], sys[pivot_index]);
+      if (row_index != pivot_index) {
+        using std::swap;
+	swap(sys[row_index], sys[pivot_index]);
+      }
       Congruence& pivot = sys[pivot_index];
       bool pivot_is_equality = pivot.is_equality();
 
@@ -428,7 +434,8 @@ Grid::simplify(Congruence_System& sys, Dimension_Kinds& dim_kinds) {
 	    reduce_equality_with_equality(row, pivot, dim);
 	  else {
 	    PPL_ASSERT(pivot.is_proper_congruence());
-	    std::swap(row, pivot);
+            using std::swap;
+	    swap(row, pivot);
 	    pivot_is_equality = true;
 	    reduce_congruence_with_equality(row, pivot, dim, sys);
 	  }
@@ -484,8 +491,9 @@ Grid::simplify(Congruence_System& sys, Dimension_Kinds& dim_kinds) {
     return_empty:
       last_row[0] = 1;
       dim_kinds.resize(1);
-      std::swap(sys.rows[0], sys.rows.back());
-      sys.erase_to_end(1);
+      using std::swap;
+      swap(sys.rows[0], sys.rows.back());
+      sys.remove_trailing_rows(num_rows - 1);
 
       PPL_ASSERT(sys.OK());
       return true;
@@ -527,7 +535,7 @@ Grid::simplify(Congruence_System& sys, Dimension_Kinds& dim_kinds) {
        num_columns);
     PPL_ASSERT(ret == true);
 #endif
-    sys.erase_to_end(reduced_num_rows);
+    sys.remove_trailing_rows(num_rows - reduced_num_rows);
   }
 
   PPL_ASSERT(sys.num_rows() == reduced_num_rows);
