@@ -1,7 +1,7 @@
 /* Polyhedron class implementation
    (non-inline widening-related member functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -20,10 +20,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Polyhedron.defs.hh"
 #include "BHRZ03_Certificate.defs.hh"
 #include "Rational_Box.hh"
@@ -98,13 +97,15 @@ PPL::Polyhedron
   // this is needed in order to widen the polyhedron and not the
   // corresponding homogenized polyhedral cone.
   const Constraint_System& y_cs = y.con_sys;
-  dimension_type num_rows = y_cs.num_rows();
+  const dimension_type old_num_rows = y_cs.num_rows();
+  dimension_type num_rows = old_num_rows;
   for (dimension_type i = 0; i < num_rows; ++i)
     if (y_cs[i].is_tautological()) {
+      using std::swap;
       --num_rows;
-      std::swap(tmp_sat_g[i], tmp_sat_g[num_rows]);
+      swap(tmp_sat_g[i], tmp_sat_g[num_rows]);
     }
-  tmp_sat_g.rows_erase_to_end(num_rows);
+  tmp_sat_g.remove_trailing_rows(old_num_rows - num_rows);
   tmp_sat_g.sort_rows();
 
   // A constraint in `con_sys' is copied to `cs_selected'
@@ -164,14 +165,8 @@ PPL::Polyhedron::H79_widening_assign(const Polyhedron& y, unsigned* tp) {
   if (x.space_dim != y.space_dim)
     throw_dimension_incompatible("H79_widening_assign(y)", "y", y);
 
-#ifndef NDEBUG
-  {
-    // We assume that y is contained in or equal to x.
-    const Polyhedron x_copy = x;
-    const Polyhedron y_copy = y;
-    PPL_ASSERT_HEAVY(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   // If any argument is zero-dimensional or empty,
   // the H79-widening behaves as the identity function.
@@ -231,7 +226,7 @@ PPL::Polyhedron::H79_widening_assign(const Polyhedron& y, unsigned* tp) {
       }
       else
 	// No tokens.
-	std::swap(x, CH78);
+	x.m_swap(CH78);
       PPL_ASSERT_HEAVY(x.OK(true));
       return;
     }
@@ -279,7 +274,7 @@ PPL::Polyhedron::H79_widening_assign(const Polyhedron& y, unsigned* tp) {
     }
     else
       // No tokens.
-      std::swap(x, H79);
+      x.m_swap(H79);
     PPL_ASSERT_HEAVY(x.OK(true));
   }
 }
@@ -320,14 +315,8 @@ PPL::Polyhedron::limited_H79_extrapolation_assign(const Polyhedron& y,
     throw_dimension_incompatible("limited_H79_extrapolation_assign(y, cs)",
 				 "cs", cs);
 
-#ifndef NDEBUG
-  {
-    // We assume that y is contained in or equal to x.
-    const Polyhedron x_copy = x;
-    const Polyhedron y_copy = y;
-    PPL_ASSERT_HEAVY(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   if (y.marked_empty())
     return;
@@ -494,7 +483,7 @@ PPL::Polyhedron
   // over `H79'.
   if (y_cert.is_stabilizing(result) && !result.contains(H79)) {
     // The technique was successful.
-    std::swap(x, result);
+    x.m_swap(result);
     PPL_ASSERT_HEAVY(x.OK(true));
     return true;
   }
@@ -564,7 +553,7 @@ PPL::Polyhedron::BHRZ03_evolving_points(const Polyhedron& y,
   // over `H79'.
   if (y_cert.is_stabilizing(result) && !result.contains(H79)) {
     // The technique was successful.
-    std::swap(x, result);
+    x.m_swap(result);
     PPL_ASSERT_HEAVY(x.OK(true));
     return true;
   }
@@ -613,7 +602,7 @@ PPL::Polyhedron::BHRZ03_evolving_rays(const Polyhedron& y,
 		if (!considered[h]) {
 		  tmp = x_g[k] * y_g[h];
 		  // The following line optimizes the computation of
-		  // tmp -= x_g[h] * y_g[k];
+		  // <CODE> tmp -= x_g[h] * y_g[k]; </CODE>
 		  sub_mul_assign(tmp, x_g[h], y_g[k]);
 		  const int clockwise
 		    = sgn(tmp);
@@ -653,7 +642,7 @@ PPL::Polyhedron::BHRZ03_evolving_rays(const Polyhedron& y,
   // Check for stabilization with respect to `y' and improvement over `H79'.
   if (y_cert.is_stabilizing(result) && !result.contains(H79)) {
     // The technique was successful.
-    std::swap(x, result);
+    x.m_swap(result);
     PPL_ASSERT_HEAVY(x.OK(true));
     return true;
   }
@@ -672,14 +661,8 @@ PPL::Polyhedron::BHRZ03_widening_assign(const Polyhedron& y, unsigned* tp) {
   if (x.space_dim != y.space_dim)
     throw_dimension_incompatible("BHRZ03_widening_assign(y)", "y", y);
 
-#ifndef NDEBUG
-  {
-    // We assume that y is contained in or equal to x.
-    const Polyhedron x_copy = x;
-    const Polyhedron y_copy = y;
-    PPL_ASSERT_HEAVY(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   // If any argument is zero-dimensional or empty,
   // the BHRZ03-widening behaves as the identity function.
@@ -749,13 +732,11 @@ PPL::Polyhedron::BHRZ03_widening_assign(const Polyhedron& y, unsigned* tp) {
   PPL_ASSERT_HEAVY(H79.OK() && x.OK() && y.OK());
 
   // No previous technique was successful: fall back to the H79 widening.
-  std::swap(x, H79);
+  x.m_swap(H79);
   PPL_ASSERT_HEAVY(x.OK(true));
 
-#ifndef NDEBUG
   // The H79 widening is always stabilizing.
   PPL_ASSERT(y_cert.is_stabilizing(x));
-#endif
 }
 
 void
@@ -794,14 +775,8 @@ PPL::Polyhedron
     throw_dimension_incompatible("limited_BHRZ03_extrapolation_assign(y, cs)",
 				 "cs", cs);
 
-#ifndef NDEBUG
-  {
-    // We assume that y is contained in or equal to x.
-    const Polyhedron x_copy = x;
-    const Polyhedron y_copy = y;
-    PPL_ASSERT_HEAVY(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   if (y.marked_empty())
     return;
