@@ -1,6 +1,6 @@
 /* Polyhedron class implementation: conversion().
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,10 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Linear_Row.defs.hh"
 #include "Linear_System.defs.hh"
 #include "Bit_Row.defs.hh"
@@ -355,6 +354,8 @@ PPL::Polyhedron::conversion(Linear_System& source,
   const dimension_type source_num_columns = source.num_columns();
   const dimension_type dest_num_columns = dest.num_columns();
 
+  using std::swap;
+
   // By construction, the number of columns of `sat' is the same as
   // the number of rows of `source'; also, the number of rows of `sat'
   // is the same as the number of rows of `dest'.
@@ -384,7 +385,7 @@ PPL::Polyhedron::conversion(Linear_System& source,
     if (source_num_redundant > 0)
       // Let the next constraint have index `k'.
       // There is no need to swap the columns of `sat' (all zeroes).
-      std::swap(source[k], source[k+source_num_redundant]);
+      swap(source[k], source[k+source_num_redundant]);
 
     Linear_Row& source_k = source[k];
 
@@ -396,10 +397,9 @@ PPL::Polyhedron::conversion(Linear_System& source,
     // constraint `source_k' and the generator `dest[i]'.  This
     // product is 0 if and only if the generator saturates the
     // constraint.
-    PPL_DIRTY_TEMP0(std::vector<Coefficient>, scalar_prod);
-    const int needed_space = dest_num_rows - scalar_prod.size();
-    if (needed_space > 0)
-      scalar_prod.insert(scalar_prod.end(), needed_space, Coefficient_zero());
+    PPL_DIRTY_TEMP(std::vector<Coefficient>, scalar_prod);
+    if (dest_num_rows > scalar_prod.size())
+      scalar_prod.resize(dest_num_rows, Coefficient_zero());
     // `index_non_zero' will indicate the first generator in `dest'
     // that does not saturate the constraint `source_k'.
     dimension_type index_non_zero = 0;
@@ -456,10 +456,10 @@ PPL::Polyhedron::conversion(Linear_System& source,
       dest.set_sorted(false);
       --num_lines_or_equalities;
       if (index_non_zero != num_lines_or_equalities) {
-	std::swap(dest[index_non_zero],
-		  dest[num_lines_or_equalities]);
-	std::swap(scalar_prod[index_non_zero],
-		  scalar_prod[num_lines_or_equalities]);
+	swap(dest[index_non_zero],
+             dest[num_lines_or_equalities]);
+	swap(scalar_prod[index_non_zero],
+             scalar_prod[num_lines_or_equalities]);
       }
       Linear_Row& dest_nle = dest[num_lines_or_equalities];
 
@@ -484,14 +484,16 @@ PPL::Polyhedron::conversion(Linear_System& source,
 	if (scalar_prod[i] != 0) {
 	  // The following fragment optimizes the computation of
 	  //
-	  // Coefficient scale = scalar_prod[i];
-	  // scale.gcd_assign(scalar_prod_nle);
-	  // Coefficient normalized_sp_i = scalar_prod[i] / scale;
-	  // Coefficient normalized_sp_n = scalar_prod_nle / scale;
-	  // for (dimension_type c = dest_num_columns; c-- > 0; ) {
-	  //   dest[i][c] *= normalized_sp_n;
-	  //   dest[i][c] -= normalized_sp_i * dest_nle[c];
-	  // }
+          // <CODE>
+	  //   Coefficient scale = scalar_prod[i];
+	  //   scale.gcd_assign(scalar_prod_nle);
+	  //   Coefficient normalized_sp_i = scalar_prod[i] / scale;
+	  //   Coefficient normalized_sp_n = scalar_prod_nle / scale;
+	  //   for (dimension_type c = dest_num_columns; c-- > 0; ) {
+	  //     dest[i][c] *= normalized_sp_n;
+	  //     dest[i][c] -= normalized_sp_i * dest_nle[c];
+	  //   }
+          // </CODE>
 	  normalize2(scalar_prod[i],
 		     scalar_prod_nle,
 		     normalized_sp_i,
@@ -520,14 +522,16 @@ PPL::Polyhedron::conversion(Linear_System& source,
 	if (scalar_prod[i] != 0) {
 	  // The following fragment optimizes the computation of
 	  //
-	  // Coefficient scale = scalar_prod[i];
-	  // scale.gcd_assign(scalar_prod_nle);
-	  // Coefficient normalized_sp_i = scalar_prod[i] / scale;
-	  // Coefficient normalized_sp_n = scalar_prod_nle / scale;
-	  // for (dimension_type c = dest_num_columns; c-- > 0; ) {
-	  //   dest[i][c] *= normalized_sp_n;
-	  //   dest[i][c] -= normalized_sp_i * dest_nle[c];
-	  // }
+          // <CODE>
+	  //   Coefficient scale = scalar_prod[i];
+	  //   scale.gcd_assign(scalar_prod_nle);
+	  //   Coefficient normalized_sp_i = scalar_prod[i] / scale;
+	  //   Coefficient normalized_sp_n = scalar_prod_nle / scale;
+	  //   for (dimension_type c = dest_num_columns; c-- > 0; ) {
+	  //     dest[i][c] *= normalized_sp_n;
+	  //     dest[i][c] -= normalized_sp_i * dest_nle[c];
+	  //   }
+          // </CODE>
 	  normalize2(scalar_prod[i],
 		     scalar_prod_nle,
 		     normalized_sp_i,
@@ -561,9 +565,9 @@ PPL::Polyhedron::conversion(Linear_System& source,
       // removed from `dest'.
       else {
 	--dest_num_rows;
-	std::swap(dest_nle, dest[dest_num_rows]);
-	std::swap(scalar_prod_nle, scalar_prod[dest_num_rows]);
-	std::swap(sat_nle, sat[dest_num_rows]);
+	swap(dest_nle, dest[dest_num_rows]);
+	swap(scalar_prod_nle, scalar_prod[dest_num_rows]);
+	swap(sat_nle, sat[dest_num_rows]);
 	// `dest' has already been set as non-sorted.
       }
       // We continue with the next constraint.
@@ -596,9 +600,9 @@ PPL::Polyhedron::conversion(Linear_System& source,
 	const int sp_sign = sgn(scalar_prod[sup_bound]);
 	if (sp_sign == 0) {
 	  // This generator has to be moved in Q=.
-	  std::swap(dest[sup_bound], dest[lines_or_equal_bound]);
-	  std::swap(scalar_prod[sup_bound], scalar_prod[lines_or_equal_bound]);
-	  std::swap(sat[sup_bound], sat[lines_or_equal_bound]);
+	  swap(dest[sup_bound], dest[lines_or_equal_bound]);
+	  swap(scalar_prod[sup_bound], scalar_prod[lines_or_equal_bound]);
+	  swap(sat[sup_bound], sat[lines_or_equal_bound]);
 	  ++lines_or_equal_bound;
 	  ++sup_bound;
 	  dest.set_sorted(false);
@@ -606,9 +610,9 @@ PPL::Polyhedron::conversion(Linear_System& source,
 	else if (sp_sign < 0) {
 	  // This generator has to be moved in Q-.
 	  --inf_bound;
-	  std::swap(dest[sup_bound], dest[inf_bound]);
-	  std::swap(scalar_prod[sup_bound], scalar_prod[inf_bound]);
-	  std::swap(sat[sup_bound], sat[inf_bound]);
+	  swap(dest[sup_bound], dest[inf_bound]);
+	  swap(scalar_prod[sup_bound], scalar_prod[inf_bound]);
+	  swap(sat[sup_bound], sat[inf_bound]);
 	  dest.set_sorted(false);
 	}
 	else
@@ -672,8 +676,10 @@ PPL::Polyhedron::conversion(Linear_System& source,
 	      // If there exist another generator that saturates
 	      // all the constraints saturated by both `dest[i]' and
 	      // `dest[j]', then they are NOT adjacent.
-	      PPL_ASSERT(sat[i].last() == ULONG_MAX || sat[i].last() < k);
-	      PPL_ASSERT(sat[j].last() == ULONG_MAX || sat[j].last() < k);
+	      PPL_ASSERT(sat[i].last() == C_Integer<unsigned long>::max
+                         || sat[i].last() < k);
+	      PPL_ASSERT(sat[j].last() == C_Integer<unsigned long>::max
+                         || sat[j].last() < k);
 
 	      // Being the union of `sat[i]' and `sat[j]',
 	      // `new_satrow' corresponds to a ray that saturates all the
@@ -728,19 +734,21 @@ PPL::Polyhedron::conversion(Linear_System& source,
 		    sat.add_recycled_row(new_satrow);
 		  }
 		  else
-                    sat[dest_num_rows].swap(new_satrow);
+                    sat[dest_num_rows].m_swap(new_satrow);
 
 		  Linear_Row& new_row = dest[dest_num_rows];
 		  // The following fragment optimizes the computation of
 		  //
-		  // Coefficient scale = scalar_prod[i];
-		  // scale.gcd_assign(scalar_prod[j]);
-		  // Coefficient normalized_sp_i = scalar_prod[i] / scale;
-		  // Coefficient normalized_sp_j = scalar_prod[j] / scale;
-		  // for (dimension_type c = dest_num_columns; c-- > 0; ) {
-		  //   new_row[c] = normalized_sp_i * dest[j][c];
-		  //   new_row[c] -= normalized_sp_j * dest[i][c];
-		  // }
+                  // <CODE>
+		  //   Coefficient scale = scalar_prod[i];
+		  //   scale.gcd_assign(scalar_prod[j]);
+		  //   Coefficient normalized_sp_i = scalar_prod[i] / scale;
+		  //   Coefficient normalized_sp_j = scalar_prod[j] / scale;
+		  //   for (dimension_type c = dest_num_columns; c-- > 0; ) {
+		  //     new_row[c] = normalized_sp_i * dest[j][c];
+		  //     new_row[c] -= normalized_sp_j * dest[i][c];
+		  //   }
+                  // </CODE>
 		  normalize2(scalar_prod[i],
 			     scalar_prod[j],
 			     normalized_sp_i,
@@ -797,9 +805,9 @@ PPL::Polyhedron::conversion(Linear_System& source,
 	  dimension_type i = dest_num_rows;
 	  while (j < bound && i > bound) {
 	    --i;
-	    std::swap(dest[i], dest[j]);
-	    std::swap(scalar_prod[i], scalar_prod[j]);
-	    std::swap(sat[i], sat[j]);
+	    swap(dest[i], dest[j]);
+	    swap(scalar_prod[i], scalar_prod[j]);
+	    swap(sat[i], sat[j]);
 	    ++j;
 	    dest.set_sorted(false);
 	  }
@@ -822,8 +830,8 @@ PPL::Polyhedron::conversion(Linear_System& source,
   // which have been swapped at the end of the system.
   if (source_num_redundant > 0) {
     PPL_ASSERT(source_num_redundant == source.num_rows() - source_num_rows);
-    source.erase_to_end(source_num_rows);
-    sat.columns_erase_to_end(source_num_rows);
+    source.remove_trailing_rows(source_num_redundant);
+    sat.remove_trailing_columns(source_num_redundant);
   }
   // If `start == 0', then `source' was sorted and remained so.
   // If otherwise `start > 0', then the two sub-system made by the
@@ -840,11 +848,12 @@ PPL::Polyhedron::conversion(Linear_System& source,
   // We may have identified some redundant rays in `dest',
   // which have been swapped at the end of the system.
   if (dest_num_rows < dest.num_rows()) {
-    dest.erase_to_end(dest_num_rows);
+    const dimension_type num_removed_rows = dest.num_rows() - dest_num_rows;
+    dest.remove_trailing_rows(num_removed_rows);
     // Be careful: we might have erased some of the non-pending rows.
     if (dest.first_pending_row() > dest_num_rows)
       dest.unset_pending_rows();
-    sat.rows_erase_to_end(dest_num_rows);
+    sat.remove_trailing_rows(num_removed_rows);
   }
   if (dest.is_sorted())
     // If the non-pending generators in `dest' are still declared to be
