@@ -1,6 +1,6 @@
 /* Utilities for termination analysis: non-inline, non-template functions.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,10 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "termination.defs.hh"
 #include "NNC_Polyhedron.defs.hh"
 
@@ -101,7 +100,7 @@ shift_unprimed_variables(Constraint_System& cs) {
     le_i_shifted += c_i.inhomogeneous_term();
     cs_shifted.insert(le_i_shifted >= 0);
   }
-  cs.swap(cs_shifted);
+  cs.m_swap(cs_shifted);
 }
 
 /*! \brief
@@ -149,7 +148,7 @@ fill_constraint_systems_MS(const Constraint_System& cs,
 			   Constraint_System& cs_out2) {
   PPL_ASSERT(cs.space_dimension() % 2 == 0);
   const dimension_type n = cs.space_dimension() / 2;
-  const dimension_type m = std::distance(cs.begin(), cs.end());
+  const dimension_type m = num_constraints(cs);
 
 #if PRINT_DEBUG_INFO
   Variable::output_function_type* p_default_output_function
@@ -178,25 +177,25 @@ fill_constraint_systems_MS(const Constraint_System& cs,
   dimension_type z = z_begin;
   for (Constraint_System::const_iterator i = cs.begin(),
 	 cs_end = cs.end(); i != cs_end; ++i) {
-    Variable vy(y);
-    Variable vz(z);
+    Variable v_y(y);
+    Variable v_z(z);
     ++y;
     ++z;
-    cs_out1.insert(vy >= 0);
-    cs_out2.insert(vz >= 0);
+    cs_out1.insert(v_y >= 0);
+    cs_out2.insert(v_z >= 0);
     const Constraint& c_i = *i;
     Coefficient_traits::const_reference b_i = c_i.inhomogeneous_term();
     if (b_i != 0) {
       // Note that b_i is to the left ot the relation sign, hence here
       // we have -= and not += just to avoid negating b_i.
-      sub_mul_assign(y_le, b_i, vy);
-      sub_mul_assign(z_le, b_i, vz);
+      sub_mul_assign(y_le, b_i, v_y);
+      sub_mul_assign(z_le, b_i, v_z);
     }
     for (dimension_type j = 2*n; j-- > 0; ) {
       Coefficient_traits::const_reference a_i_j = c_i.coefficient(Variable(j));
       if (a_i_j != 0) {
-        add_mul_assign(y_les[j], a_i_j, vy);
-        add_mul_assign(z_les[j], a_i_j, vz);
+        add_mul_assign(y_les[j], a_i_j, v_y);
+        add_mul_assign(z_les[j], a_i_j, v_z);
       }
     }
   }
@@ -363,8 +362,8 @@ fill_constraint_system_PR(const Constraint_System& cs_before,
   PPL_ASSERT(cs_after.space_dimension() % 2 == 0);
   PPL_ASSERT(2*cs_before.space_dimension() == cs_after.space_dimension());
   const dimension_type n = cs_before.space_dimension();
-  const dimension_type r = distance(cs_before.begin(), cs_before.end());
-  const dimension_type s = distance(cs_after.begin(), cs_after.end());
+  const dimension_type r = num_constraints(cs_before);
+  const dimension_type s = num_constraints(cs_after);
   const dimension_type m = r + s;
 
   // Make sure linear expressions are not reallocated multiple times.
@@ -440,7 +439,7 @@ fill_constraint_system_PR_original(const Constraint_System& cs,
                                    Linear_Expression& le_out) {
   PPL_ASSERT(cs.space_dimension() % 2 == 0);
   const dimension_type n = cs.space_dimension() / 2;
-  const dimension_type m = distance(cs.begin(), cs.end());
+  const dimension_type m = num_constraints(cs);
 
   // Make sure linear expressions are not reallocated multiple times.
   if (m > 0)
@@ -536,7 +535,7 @@ all_affine_ranking_functions_MS(const Constraint_System& cs,
   Variable::set_output_function(output_function_MS);
 
   output_function_MS_n = n;
-  output_function_MS_m = std::distance(cs.begin(), cs.end());
+  output_function_MS_m = num_constraints(cs);
 
   std::cout << "*** ph1 projected ***" << std::endl;
   output_function_MS_which = 4;
@@ -557,7 +556,7 @@ all_affine_ranking_functions_MS(const Constraint_System& cs,
   Variable::set_output_function(p_default_output_function);
 #endif
 
-  mu_space.swap(ph1);
+  mu_space.m_swap(ph1);
 }
 
 void
@@ -581,7 +580,7 @@ all_affine_quasi_ranking_functions_MS(const Constraint_System& cs,
   Variable::set_output_function(output_function_MS);
 
   output_function_MS_n = n;
-  output_function_MS_m = std::distance(cs.begin(), cs.end());
+  output_function_MS_m = num_constraints(cs);
 
   std::cout << "*** ph1 projected ***" << std::endl;
   output_function_MS_which = 4;
@@ -594,8 +593,8 @@ all_affine_quasi_ranking_functions_MS(const Constraint_System& cs,
   Variable::set_output_function(p_default_output_function);
 #endif
 
-  decreasing_mu_space.swap(ph1);
-  bounded_mu_space.swap(ph2);
+  decreasing_mu_space.m_swap(ph1);
+  bounded_mu_space.m_swap(ph2);
 }
 
 bool
@@ -625,8 +624,8 @@ termination_test_PR(const Constraint_System& cs_before,
     = Variable::get_output_function();
   Variable::set_output_function(output_function_PR);
 
-  output_function_PR_r = distance(cs_before.begin(), cs_before.end());
-  output_function_PR_s = distance(cs_after.begin(), cs_after.end());
+  output_function_PR_r = num_constraints(cs_before);
+  output_function_PR_s = num_constraints(cs_after);
 
   std::cout << "*** cs_mip ***" << std::endl;
   using namespace IO_Operators;
@@ -657,8 +656,8 @@ one_affine_ranking_function_PR(const Constraint_System& cs_before,
     = Variable::get_output_function();
   Variable::set_output_function(output_function_PR);
 
-  output_function_PR_r = distance(cs_before.begin(), cs_before.end());
-  output_function_PR_s = distance(cs_after.begin(), cs_after.end());
+  output_function_PR_r = num_constraints(cs_before);
+  output_function_PR_s = num_constraints(cs_after);
 
   std::cout << "*** cs_mip ***" << std::endl;
   using namespace IO_Operators;
@@ -710,7 +709,7 @@ one_affine_ranking_function_PR_original(const Constraint_System& cs,
                                         Generator& mu) {
   PPL_ASSERT(cs.space_dimension() % 2 == 0);
   const dimension_type n = cs.space_dimension() / 2;
-  const dimension_type m = std::distance(cs.begin(), cs.end());
+  const dimension_type m = num_constraints(cs);
 
   Constraint_System cs_mip;
   Linear_Expression le_ineq;
@@ -772,8 +771,8 @@ all_affine_ranking_functions_PR(const Constraint_System& cs_before,
     = Variable::get_output_function();
   Variable::set_output_function(output_function_PR);
 
-  output_function_PR_r = distance(cs_before.begin(), cs_before.end());
-  output_function_PR_s = distance(cs_after.begin(), cs_after.end());
+  output_function_PR_r = num_constraints(cs_before);
+  output_function_PR_s = num_constraints(cs_after);
 
   std::cout << "*** cs_eqs ***" << std::endl;
   using namespace IO_Operators;
@@ -785,7 +784,7 @@ all_affine_ranking_functions_PR(const Constraint_System& cs_before,
   NNC_Polyhedron ph(cs_eqs);
   ph.add_constraint(le_ineq < 0);
   // u_3 corresponds to space dimensions 0, ..., s - 1.
-  const dimension_type s = distance(cs_after.begin(), cs_after.end());
+  const dimension_type s = num_constraints(cs_after);
   ph.remove_higher_space_dimensions(s);
 
 #if PRINT_DEBUG_INFO
@@ -857,7 +856,7 @@ all_affine_ranking_functions_PR_original(const Constraint_System& cs,
                                          NNC_Polyhedron& mu_space) {
   PPL_ASSERT(cs.space_dimension() % 2 == 0);
   const dimension_type n = cs.space_dimension() / 2;
-  const dimension_type m = distance(cs.begin(), cs.end());
+  const dimension_type m = num_constraints(cs);
 
   if (m == 0) {
     // If there are no constraints at all, we have non-termination,
@@ -875,7 +874,6 @@ all_affine_ranking_functions_PR_original(const Constraint_System& cs,
   // lambda_2 corresponds to space dimensions m, ..., 2*m-1.
   Variables_Set lambda1(Variable(0), Variable(m-1));
   ph.remove_space_dimensions(lambda1);
-  //ph.remove_higher_space_dimensions(m);
 
 #if PRINT_DEBUG_INFO
   std::cout << "*** ph ***" << std::endl;
@@ -885,13 +883,13 @@ all_affine_ranking_functions_PR_original(const Constraint_System& cs,
 #endif
 
   const Generator_System& gs_in = ph.generators();
-  Generator_System gs_out;
   Generator_System::const_iterator gs_in_it = gs_in.begin();
   Generator_System::const_iterator gs_in_end = gs_in.end();
   if (gs_in_it == gs_in_end)
     // The system is unsatisfiable.
     mu_space = NNC_Polyhedron(n + 1, EMPTY);
   else {
+    Generator_System gs_out;
     for ( ; gs_in_it != gs_in_end; ++gs_in_it) {
       const Generator& g = *gs_in_it;
       Linear_Expression le;
